@@ -21,7 +21,7 @@ if TYPE_CHECKING:
     """Animation keys are the id of the object and the attribute being animated."""
 
 EasingFunction = Callable[[float], float]
-"""Signature for a function that parametrises animation speed.
+"""Signature for a function that parametrizes animation speed.
 
 An easing function must map the interval [0, 1] into the interval [0, 1].
 """
@@ -191,7 +191,7 @@ class BoundAnimator:
             attribute: Name of the attribute to animate.
             value: The value to animate to.
             final_value: The final value of the animation. Defaults to `value` if not set.
-            duration: The duration of the animate.
+            duration: The duration (in seconds) of the animation.
             speed: The speed of the animation.
             delay: A delay (in seconds) before the animation starts.
             easing: An easing method.
