@@ -42,7 +42,7 @@ class Underline(Widget):
     """
     | Class | Description |
     | :- | :- |
-    | `underline-bar` | Style of the bar (may be used to change the color). |
+    | `underline--bar` | Style of the bar (may be used to change the color). |
     """
 
     highlight_start = reactive(0)
@@ -510,7 +510,7 @@ class Tabs(Widget, can_focus=True):
             An optionally awaitable object that waits for the tab to be removed.
         """
         if not tab_or_id:
-            return AwaitComplete(self.app._remove_nodes([], None))
+            return AwaitComplete()
 
         if isinstance(tab_or_id, Tab):
             remove_tab = tab_or_id
@@ -518,7 +518,7 @@ class Tabs(Widget, can_focus=True):
             try:
                 remove_tab = self.query_one(f"#tabs-list > #{tab_or_id}", Tab)
             except NoMatches:
-                return AwaitComplete(self.app._remove_nodes([], None))
+                return AwaitComplete()
 
         removing_active_tab = remove_tab.has_class("-active")
         next_tab = self._next_active
